@@ -22,14 +22,14 @@ else:
 __all__ = (
     "DescribeObjectsPaginatorName",
     "ListPipelinesPaginatorName",
-    "OperatorType",
+    "OperatorTypeType",
     "QueryObjectsPaginatorName",
-    "TaskStatus",
+    "TaskStatusType",
 )
 
 
 DescribeObjectsPaginatorName = Literal["describe_objects"]
 ListPipelinesPaginatorName = Literal["list_pipelines"]
-OperatorType = Literal["BETWEEN", "EQ", "GE", "LE", "REF_EQ"]
+OperatorTypeType = Literal["BETWEEN", "EQ", "GE", "LE", "REF_EQ"]
 QueryObjectsPaginatorName = Literal["query_objects"]
-TaskStatus = Literal["FAILED", "FALSE", "FINISHED"]
+TaskStatusType = Literal["FAILED", "FALSE", "FINISHED"]
